@@ -1,5 +1,5 @@
 # Perl module: Client ModBus / TCP class 1
-#     Version: 1.52
+#     Version: 1.53
 #     Website: https://github.com/sourceperl/MBclient/
 #        Date: 2014-07-04
 #     License: MIT (http://http://opensource.org/licenses/mit-license.php)
@@ -32,7 +32,7 @@ use Exporter;
 use Socket;
 use bytes;
 
-our $VERSION = '1.52';
+our $VERSION = '1.53';
 
 ##
 ## Constant
@@ -717,7 +717,13 @@ You can have a look at http://en.wikipedia.org/wiki/Modbus for details.
 
 =head1 INSTALL
 
-To install this module from GitHub:
+You can install this module from:
+
+CPAN, the easy way:
+
+    sudo perl -MCPAN -e'install MBclient'
+
+GitHub:
 
     git clone https://github.com/sourceperl/MBclient.git
     cd MBclient
@@ -726,8 +732,6 @@ To install this module from GitHub:
     make test
     sudo make install
 
-This module is also available from CPAN.
-
 =head1 DEPENDENCIES
 
 This module requires no other module or librarie.
